﻿$(document).ready(function () {
    var selectedIds = [];

    var aId = $('#assessmentId').text();
    
    var hostDatatable = $('#hostDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/hosts",
            "type": "POST",
            "datatype": "json",
            "data": {
                assessmentId: aId
            }
        },
        "columnDefs": [
            { "targets": [0], "orderable": false, "searchable": false, },
            { "targets": [1], "visible": false, "searchable": false, },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        var text = document.createTextNode(data);
                        var safeData = text.textContent || text.nodeValue;

                        // Escaping for HTML attribute
                        var escapedSafeDataForAttribute = safeData.replace(/"/g, '&quot;').replace(/'/g, '&#39;');

                        return type === 'display' && safeData.length > 100 ?
                            '<span data-toggle="tooltip" title="' + escapedSafeDataForAttribute + '">' + safeData.substring(0, 100) + '...' + '</span>' :
                            safeData;
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./View?id=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>
<a href="/vulnerabilities/list?assessmentId=` + row.assessmentId + `&hostId=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View Vulnerabilities"><i class="fa-solid fa-bug"></i></a>
`;
                }
            },
            { "data": "id", "name": "Id" },
            {
                "name": "tags",
                "render": function (data, type, row, meta) {
                    var tags = row.tags ? row.tags.split(',') : [];
                    if (tags.length === 0) {
                        return null;
                    }

                    var badges = '';
                    tags.forEach(function (tag) {
                        if (tag.toLowerCase() === 'new') {
                            badges += `<span class="badge rounded-pill bg-primary" title="The host was not identified in the previous assessment">NEW</span> `;
                        }
                        else if (tag.toLowerCase() === 'decommissioned') {
                            badges += `<span class="badge rounded-pill bg-danger" title="The host was not identified in the current assessment, but it was identified in the previous assessment">DECOM</span> `;
                        }
                        else if (tag.toLowerCase() === 'unknown') {
                            badges += `<span class="badge rounded-pill bg-secondary" title="It is unknown if this host is new or decommissioned when compared with a previous assessment. To determine the status, manually trigger the compare function (marked with a shield icon, available on the hosts page). Please note that at least two assessments are required to use this feature.">UNKNOWN</span> `;
                        }
                        else {
                            badges += `<span class="badge rounded-pill bg-info">` + tag.toUpperCase() + `</span> `;
                        }
                    });
                    return badges.trim();
                }
            },
            { "data": "ip", "name": "IP", "defaultContent": "" },
            { "data": "name", "name": "Name", "defaultContent": "" },
            { "data": "operatingSystem", "name": "Operating System", "defaultContent": "" },
            { "data": "fqdn", "name": "FQDN", "defaultContent": "" },
            { "data": "netbiosName", "name": "Netbios Name", "defaultContent": "" },
            { "data": "description", "name": "Description", "defaultContent": "" },
            { "data": "numberOfVulnerabilities", "name": "# Vulnerabilities", "orderSequence": ["desc", "asc"], "defaultContent": 0 },
            { "data": "numberOfCriticalVulnerabilities", "name": "# Critical", "orderSequence": ["desc", "asc"], "defaultContent": 0 },
            { "data": "numberOfHighVulnerabilities", "name": "# High", "orderSequence": ["desc", "asc"], "defaultContent": 0 },
            { "data": "numberOfMediumVulnerabilities", "name": "# Medium", "orderSequence": ["desc", "asc"], "defaultContent": 0 },
            { "data": "numberOfLowVulnerabilities", "name": "# Low", "orderSequence": ["desc", "asc"], "defaultContent": 0 },
            { "data": "numberOfInformationalVulnerabilities", "name": "# Informational", "orderSequence": ["desc", "asc"], "defaultContent": 0 },
        ],
    });

    /*
     * Handle table select
     * */
    hostDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = hostDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            if (selectedIds.length > 1) {
                $('#btnEditMultipleHosts').removeClass('disabled');
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });

    /*
     * Handle table deselect
     * */
    hostDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = hostDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            if (selectedIds.length < 2) {
                $('#btnEditMultipleHosts').addClass('disabled', 'disabled');
                $('#btnEditMultipleHosts').attr("href", "broken" + selectedIds.toString());
            }
            else {
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });


    /*
     * Show/hide columns
     * */
    $('button.toggle-vis').on('click', function (e) {
        e.preventDefault();

        // Get the column API object
        var column = hostDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('input.toogle-column-visibility').on('click', function (e) {
        // Get the column API object
        var column = hostDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('button.toogle-column-visibility-select-special').on('click', function (e) {
        if (this.id === "customSwitchShowAll") {
            showAllColumns();
        }
        else if (this.id === "customSwitchHideAll") {
            hideAllColumns();
        }
    });

    /*
     * Set correct state on visibility switches when modul loads
     * */
    $('a.show-hide-columns').on('click', function (e) {
        setCorrectSwitchStates();
    });

    function setCorrectSwitchStates() {
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            var column = hostDatatable.column($(allCheckboxes[i]).attr('data-column'));
            var isVisible = column.visible();
            if (isVisible == true) {
                allCheckboxes[i].checked = true;
            }
            else {
                allCheckboxes[i].checked = false;
            }
        }
    }

    function showAllColumns() {
        hostDatatable.columns().visible(true);
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");
        hostDatatable.columns([1]).visible(false); //Exceptions, always hide this column
        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = true;
        }
    }

    function hideAllColumns() {
        hostDatatable.columns().visible(false);
        hostDatatable.columns([0]).visible(true); //Exceptions, never hide this column
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = false;
        }
    }
});