﻿$(document).ready(function () {
    var selectedIds = [];

    var aId = $('#assessmentId').text();

    var transformDatatable = $('#transformDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/transforms/List",
            "type": "POST",
            "datatype": "json",
            "data": {
                assessmentId: aId,
            }
        },
        "columnDefs": [
            { "targets": [0], "orderable": false, "searchable": false, "render": DataTable.render.text() },
            { "targets": [1], "visible": false, "searchable": false, "render": DataTable.render.text() },
            {
                "targets": [5],
                render: function (data, type, row) {
                    if (row.hasLinkedTextRewrite == false) {
                        return "false";
                    }
                    else {
                        return "true";
                    }
                }
            },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        var text = document.createTextNode(data);
                        var safeData = text.textContent || text.nodeValue;

                        return type === 'display' && safeData.length > 100 ?
                            safeData.substring(0, 100) + '…' :
                            safeData;
                    }
                    else {
                        return " ";
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./View?id=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>
`;
                }
            },
            { "data": "id", "name": "Id", "render": DataTable.render.text() },
            { "data": "name", "name": "Name", "render": DataTable.render.text() },
            { "data": "numberOfInputs", "name": "Inputs", "render": DataTable.render.text() },
            { "data": "outputPluginId", "name": "Output Plugin Id", "render": DataTable.render.text() },
            { "data": "hasLinkedTextRewrite", "name": "Has Linked Text Rewrite", "render": DataTable.render.text() },
            { "data": "description", "name": "Description", "render": DataTable.render.text() },
            { "data": "notes", "name": "Notes", "render": DataTable.render.text() },
        ],
    });

    /*
     * Handle table select
     * */
    transformDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = transformDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });

    /*
     * Handle table deselect
     * */
    transformDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = transformDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });
});